from django.conf import settings
from django.contrib.admin.templatetags.admin_static import static
from django.contrib.admin.widgets import AdminTextareaWidget
from django.contrib.postgres.forms import forms
from django.template.loader import get_template
from django.utils.safestring import mark_safe


class HStoreFormWidget(AdminTextareaWidget):

    @property
    def media(self):
        internal_js = [
            "django_admin_hstore_widget/underscore-min.js",
            "django_admin_hstore_widget/django_admin_hstore_widget.js"
        ]

        js = [static("admin/js/%s" % path) for path in internal_js]

        return forms.Media(js=js)

    def render(self, name, value, attrs=None, renderer=None):
        if attrs is None:
            attrs = {}
            # it's called "original" because it will be replaced by a copy
        attrs['class'] = 'hstore-original-textarea'

        # get default HTML from AdminTextareaWidget
        html = super(HStoreFormWidget, self).render(name, value, attrs)

        # prepare template context
        template_context = {
            'field_name': name,
            'STATIC_URL': settings.STATIC_URL,
        }

        # get template object
        template = get_template('admin/django_admin_hstore_widget.html')
        # render additional html
        additional_html = template.render(template_context)

        # append additional HTML and mark as safe
        html = html + additional_html
        html = mark_safe(html)

        return html



import os
from setuptools import setup, find_packages

version = '0.1.2'


def get_package_data(package):
    """
    Return all files under the root package, that are not in a
    package themselves.
    """
    walk = [(dirpath.replace(package + os.sep, '', 1), filenames)
            for dirpath, dirnames, filenames in os.walk(package)
            if not os.path.exists(os.path.join(dirpath, '__init__.py'))]

    filepaths = []
    for base, filenames in walk:
        filepaths.extend([os.path.join(base, filename)
                          for filename in filenames])
    return {package: filepaths}


setup(
    name='django-admin-hstore-widget',
    version=version,
    description="Widget and Field to properly render HStore data in Django-Admin",
    keywords="django admin hstore render",
    author='Alexandre Dufour',
    author_email='adufour@poka.io',
    maintainer='Alexandre Dufour',
    maintainer_email='adufour@poka.io',
    url='https://github.com/PokaInc/django-admin-hstore-widget',
    packages=find_packages(),
    package_data=get_package_data('django_admin_hstore_widget'),
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    zip_safe=False,
)
